aboutsummaryrefslogtreecommitdiff
path: root/nuttx/include
diff options
context:
space:
mode:
authorpatacongo <patacongo@7fd9a85b-ad96-42d3-883c-3090e2eb8679>2012-06-20 17:37:20 +0000
committerpatacongo <patacongo@7fd9a85b-ad96-42d3-883c-3090e2eb8679>2012-06-20 17:37:20 +0000
commita81c274be884230a247ae68a8c707bbf5a6ff2e1 (patch)
tree7dddb55bc7aa7a8e62b501d4d263df75d17e2ed5 /nuttx/include
parent048a62dba9937ed11e4e9cdeadddd870a043b819 (diff)
downloadpx4-firmware-a81c274be884230a247ae68a8c707bbf5a6ff2e1.tar.gz
px4-firmware-a81c274be884230a247ae68a8c707bbf5a6ff2e1.tar.bz2
px4-firmware-a81c274be884230a247ae68a8c707bbf5a6ff2e1.zip
PIC32MX1/2 pin selection logic; Mirtoo LEDs, SPI2, and UART2 configuration
git-svn-id: https://nuttx.svn.sourceforge.net/svnroot/nuttx/trunk@4853 7fd9a85b-ad96-42d3-883c-3090e2eb8679
Diffstat (limited to 'nuttx/include')
-rw-r--r--nuttx/include/nuttx/spi.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/nuttx/include/nuttx/spi.h b/nuttx/include/nuttx/spi.h
index 727fd87de..6448dc7c5 100644
--- a/nuttx/include/nuttx/spi.h
+++ b/nuttx/include/nuttx/spi.h
@@ -355,7 +355,9 @@ enum spi_dev_e
SPIDEV_ETHERNET, /* Select SPI ethernet device */
SPIDEV_DISPLAY, /* Select SPI LCD/OLED display device */
SPIDEV_WIRELESS, /* Select SPI Wireless device */
- SPIDEV_TOUCHSCREEN /* Select SPI touchscreen device */
+ SPIDEV_TOUCHSCREEN, /* Select SPI touchscreen device */
+ SPIDEV_EXPANDER, /* Select SPI I/O expander device */
+ SPIDEV_MUX /* Select SPI multiplexer device */
};
/* Certain SPI devices may required differnt clocking modes */